| Title: | Reading and Saving DICOM Image Files |
|---|---|
| Description: | This function provides an interface between 'Matlab' and 'R' in facilitating fast processing for reading and saving DICOM images. |
| Authors: | Shu Jiang [aut, cre] |
| Maintainer: | Shu Jiang <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.0.3 |
| Built: | 2026-05-09 08:49:35 UTC |
| Source: | https://github.com/cran/DICOMread |
Function to check whether Matlab is available
Avb_fun()Avb_fun()
a boolean variable
Avb_fun()Avb_fun()
Function to check whether the DICOM matrix has been saved successfully
check_mat(file_name)check_mat(file_name)
file_name |
the name of the .csv file saved under form_mat_fun() |
a boolean variable
Function to construct and save data matrix from the DICOM file
form_mat_fun(path_in, out_name)form_mat_fun(path_in, out_name)
path_in |
afile path for the DICOM variable, needs to be a string |
out_name |
name of the saved .csv file, need to be a string |
saved .csv file of the data matrix