Welcome to ClientVPS Mirrors

Help for package DICOMread
Title: Reading and Saving DICOM Image Files
Version: 0.0.0.3
Description: This function provides an interface between 'Matlab' and 'R' in facilitating fast processing for reading and saving DICOM images.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.1.1
Imports: matlabr
Depends: R (≥ 2.10)
NeedsCompilation: no
Packaged: 2021-05-15 17:17:59 UTC; shujiang
Author: Shu Jiang ORCID iD [aut, cre]
Maintainer: Shu Jiang <jiang.shu@wustl.edu>
Repository: CRAN
Date/Publication: 2021-05-15 17:30:02 UTC

Function to check whether Matlab is available

Description

Function to check whether Matlab is available

Usage

Avb_fun()

Value

a boolean variable

Examples

Avb_fun()


Function to check whether the DICOM matrix has been saved successfully

Description

Function to check whether the DICOM matrix has been saved successfully

Usage

check_mat(file_name)

Arguments

file_name

the name of the .csv file saved under form_mat_fun()

Value

a boolean variable


Function to construct and save data matrix from the DICOM file

Description

Function to construct and save data matrix from the DICOM file

Usage

form_mat_fun(path_in, out_name)

Arguments

path_in

afile path for the DICOM variable, needs to be a string

out_name

name of the saved .csv file, need to be a string

Value

saved .csv file of the data matrix

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.